@@ -1,13 +1,23 @@
+import os
 import unittest
+
+import six
+
 import bmemcached
 from bmemcached.compat import long, unicode
 
+if six.PY3:
+    from unittest import mock
+else:
+    import mock
+
 
 class MemcachedTests(unittest.TestCase):
     def setUp(self):
-        self.server = '127.0.0.1:11211'
+        self.server = '{}:11211'.format(os.environ['MEMCACHED_HOST'])
         self.server = '/tmp/memcached.sock'
-        self.client = bmemcached.Client(self.server)
+        self.client = bmemcached.Client(self.server, 'user', 'password')
+        self.reset()
 
     def tearDown(self):
         self.reset()
@@ -29,10 +39,20 @@ class MemcachedTests(unittest.TestCase):
         self.client.set_multi(
             dict((unicode(k), b'value') for k in range(32767)))
 
-    def testGet(self):
+    def testGetSimple(self):
         self.client.set('test_key', 'test')
         self.assertEqual('test', self.client.get('test_key'))
 
+    def testGetBytes(self):
+        # Ensure the code is 8-bit clean.
+        value = b'\x01z\x7f\x00\x80\xfe\xff\x00'
+        self.client.set('test_key', value)
+        self.assertEqual(value, self.client.get('test_key'))
+
+    def testGetDecodedText(self):
+        self.client.set('test_key', u'\u30b7')
+        self.assertEqual(u'\u30b7', self.client.get('test_key'))
+
     def testCas(self):
         value, cas = self.client.gets('nonexistant')
         self.assertTrue(value is None)
@@ -60,7 +80,7 @@ class MemcachedTests(unittest.TestCase):
         value, cas = self.client.gets('test_key')
 
         # If a different CAS value is supplied, the key is not deleted.
-        self.assertFalse(self.client.delete('test_key', cas=cas+1))
+        self.assertFalse(self.client.delete('test_key', cas=cas + 1))
         self.assertEqual('test', self.client.get('test_key'))
 
         # If the correct CAS value is supplied, the key is deleted.
@@ -112,6 +132,10 @@ class MemcachedTests(unittest.TestCase):
         self.client.set('test_key', '')
         self.assertEqual('', self.client.get('test_key'))
 
+    def testGetUnicodeString(self):
+        self.client.set('test_key', u'\xac')
+        self.assertEqual(u'\xac', self.client.get('test_key'))
+
     def testGetMulti(self):
         self.assertTrue(self.client.set_multi({
             'test_key': 'value',
@@ -203,7 +227,7 @@ class MemcachedTests(unittest.TestCase):
 
 class TimeoutMemcachedTests(unittest.TestCase):
     def setUp(self):
-        self.server = '127.0.0.1:11211'
+        self.server = '{}:11211'.format(os.environ['MEMCACHED_HOST'])
         self.client = None
 
     def tearDown(self):
@@ -217,6 +241,13 @@ class TimeoutMemcachedTests(unittest.TestCase):
     def testTimeout(self):
         self.client = bmemcached.Client(self.server, 'user', 'password',
                                         socket_timeout=0.00000000000001)
+
+        for proto in self.client._servers:
+            # Set up a mock connection that gives the impression of
+            # timing out in every recv() call.
+            proto.connection = mock.Mock()
+            proto.connection.recv.return_value = b''
+
         self.client.set('timeout_key', 'test')
         self.assertEqual(self.client.get('timeout_key'), None)
 
